@@ -2,9 +2,7 @@
 """`TempFS` opener definition.
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 import typing
 
@@ -13,8 +11,9 @@ from .registry import registry
 
 if typing.TYPE_CHECKING:
     from typing import Text
-    from .parse import ParseResult
+
     from ..tempfs import TempFS  # noqa: F401
+    from .parse import ParseResult
 
 
 @registry.install
